use toml::{Table, Value};

#[derive(Debug, Clone)]
pub struct Config {
    pub build_dir: String,
    pub compile_commands: bool,
    pub compile_commands_target: String,
}

impl Config {
    pub fn get_default() -> Self {
        Config {
            build_dir: String::from("build"),
            compile_commands: false,
            compile_commands_target: String::from(""),
        }
    }
    pub fn set(&mut self, table: &Table) {
        for k in table.keys() {
            match &*k.to_owned() {
                "build_dir" => {
                    if let Value::String(s) = table.get(k).unwrap() {
                        self.build_dir = s.to_owned();
                    } else {
                        panic!("error parsing config table: {k} invalid type, must be a string.");
                    }
                }
                "compile_commands" => {
                    if let Value::Boolean(b) = table.get(k).unwrap() {
                        //eprintln!("warn: config.compile_commands has no functionality (yet)");
                        self.compile_commands = *b;
                    } else {
                        panic!("error parsing config table: {k} invalid type, must be a boolean.");
                    }
                }
                "compile_commands_target" => {
                    if let Value::String(s) = table.get(k).unwrap() {
                        self.compile_commands_target = s.to_owned();
                    } else {
                        panic!("error parsing config table: {k} invalid type, must be a string.");
                    }
                }
                _ => panic!("error parsing config table: unrecognized key {k}."),
            }
        }
    }
}
